+++
title = "Code-fenced source blocks with backticks"
tags = ["src-block", "code-fence", "backticks"]
draft = false
+++

This code block contains a fenced code block with 4 backticks:

`````md
````emacs-lisp
(message "Hello")
````
`````

This code block contains a fenced code block with 3 backticks:

`````md
```emacs-lisp
(message "Hello again")
```
`````

This code block contains no backticks:

`````emacs-lisp
(message "Hello again x2")
`````

This code block again contains a fenced code block with 4 backticks:

`````md
````emacs-lisp
(message "Hello again x3")
````
`````

This code block contains a fenced code block with 6 backticks:

```````md
``````emacs-lisp
(message "Hello again x4")
``````
```````

This code block again contains a fenced code block with 3 backticks:

```````md
```emacs-lisp
(message "Hello again x5")
```
```````

This code block once again contains no backticks:

```````emacs-lisp
(message "Hello again x6")
```````
